Class: Google::Apis::CloudsupportV2::CaseClassification

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/cloudsupport_v2/classes.rb,
lib/google/apis/cloudsupport_v2/representations.rb,
lib/google/apis/cloudsupport_v2/representations.rb

Overview

A Case Classification represents the topic that a case is about. It's very important to use accurate classifications, because they're used to route your cases to specialists who can help you. A classification always has an ID that is its unique identifier. A valid ID is required when creating a case.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ CaseClassification

Returns a new instance of CaseClassification.



342
343
344
# File 'lib/google/apis/cloudsupport_v2/classes.rb', line 342

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#display_nameString

A display name for the classification. The display name is not static and can change. To uniquely and consistently identify classifications, use the CaseClassification.id field. Corresponds to the JSON property displayName

Returns:

  • (String)


330
331
332
# File 'lib/google/apis/cloudsupport_v2/classes.rb', line 330

def display_name
  @display_name
end

#idString

The unique ID for a classification. Must be specified for case creation. To retrieve valid classification IDs for case creation, use caseClassifications. search. Classification IDs returned by caseClassifications.search are guaranteed to be valid for at least 6 months. If a given classification is deactiveated, it will immediately stop being returned. After 6 months, case. create requests using the classification ID will fail. Corresponds to the JSON property id

Returns:

  • (String)


340
341
342
# File 'lib/google/apis/cloudsupport_v2/classes.rb', line 340

def id
  @id
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



347
348
349
350
# File 'lib/google/apis/cloudsupport_v2/classes.rb', line 347

def update!(**args)
  @display_name = args[:display_name] if args.key?(:display_name)
  @id = args[:id] if args.key?(:id)
end