Class: Google::Apis::CloudsupportV2::ListCasesResponse

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/cloudsupport_v2/classes.rb,
lib/google/apis/cloudsupport_v2/representations.rb,
lib/google/apis/cloudsupport_v2/representations.rb

Overview

The response message for the ListCases endpoint.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ListCasesResponse

Returns a new instance of ListCasesResponse.



836
837
838
# File 'lib/google/apis/cloudsupport_v2/classes.rb', line 836

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#casesArray<Google::Apis::CloudsupportV2::Case>

The list of cases associated with the parent after any filters have been applied. Corresponds to the JSON property cases



827
828
829
# File 'lib/google/apis/cloudsupport_v2/classes.rb', line 827

def cases
  @cases
end

#next_page_tokenString

A token to retrieve the next page of results. Set this in the page_token field of subsequent cases.list requests. If unspecified, there are no more results to retrieve. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


834
835
836
# File 'lib/google/apis/cloudsupport_v2/classes.rb', line 834

def next_page_token
  @next_page_token
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



841
842
843
844
# File 'lib/google/apis/cloudsupport_v2/classes.rb', line 841

def update!(**args)
  @cases = args[:cases] if args.key?(:cases)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
end