Class: Google::Apis::CloudsupportV2::ObjectIdProp
- Inherits:
-
Object
- Object
- Google::Apis::CloudsupportV2::ObjectIdProp
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/cloudsupport_v2/classes.rb,
lib/google/apis/cloudsupport_v2/representations.rb,
lib/google/apis/cloudsupport_v2/representations.rb
Overview
gdata.* are outside protos with mising documentation
Instance Attribute Summary collapse
-
#bucket_name ⇒ String
gdata.* are outside protos with mising documentation Corresponds to the JSON property
bucketName. -
#generation ⇒ Fixnum
gdata.* are outside protos with mising documentation Corresponds to the JSON property
generation. -
#object_name ⇒ String
gdata.* are outside protos with mising documentation Corresponds to the JSON property
objectName.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ObjectIdProp
constructor
A new instance of ObjectIdProp.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ObjectIdProp
Returns a new instance of ObjectIdProp.
1129 1130 1131 |
# File 'lib/google/apis/cloudsupport_v2/classes.rb', line 1129 def initialize(**args) update!(**args) end |
Instance Attribute Details
#bucket_name ⇒ String
gdata.* are outside protos with mising documentation
Corresponds to the JSON property bucketName
1117 1118 1119 |
# File 'lib/google/apis/cloudsupport_v2/classes.rb', line 1117 def bucket_name @bucket_name end |
#generation ⇒ Fixnum
gdata.* are outside protos with mising documentation
Corresponds to the JSON property generation
1122 1123 1124 |
# File 'lib/google/apis/cloudsupport_v2/classes.rb', line 1122 def generation @generation end |
#object_name ⇒ String
gdata.* are outside protos with mising documentation
Corresponds to the JSON property objectName
1127 1128 1129 |
# File 'lib/google/apis/cloudsupport_v2/classes.rb', line 1127 def object_name @object_name end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1134 1135 1136 1137 1138 |
# File 'lib/google/apis/cloudsupport_v2/classes.rb', line 1134 def update!(**args) @bucket_name = args[:bucket_name] if args.key?(:bucket_name) @generation = args[:generation] if args.key?(:generation) @object_name = args[:object_name] if args.key?(:object_name) end |