Class: Google::Apis::CloudsupportV2::Media
- Inherits:
-
Object
- Object
- Google::Apis::CloudsupportV2::Media
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/cloudsupport_v2/classes.rb,
lib/google/apis/cloudsupport_v2/representations.rb,
lib/google/apis/cloudsupport_v2/representations.rb
Overview
gdata.* are outside protos with mising documentation
Instance Attribute Summary collapse
-
#algorithm ⇒ String
gdata.* are outside protos with mising documentation Corresponds to the JSON property
algorithm. -
#bigstore_object_ref ⇒ String
gdata.* are outside protos with mising documentation Corresponds to the JSON property
bigstoreObjectRefNOTE: Values are automatically base64 encoded/decoded in the client library. -
#blob_ref ⇒ String
gdata.* are outside protos with mising documentation Corresponds to the JSON property
blobRefNOTE: Values are automatically base64 encoded/decoded in the client library. -
#blobstore2_info ⇒ Google::Apis::CloudsupportV2::Blobstore2Info
gdata.* are outside protos with mising documentation Corresponds to the JSON property
blobstore2Info. -
#composite_media ⇒ Array<Google::Apis::CloudsupportV2::CompositeMedia>
gdata.* are outside protos with mising documentation Corresponds to the JSON property
compositeMedia. -
#content_type ⇒ String
gdata.* are outside protos with mising documentation Corresponds to the JSON property
contentType. -
#content_type_info ⇒ Google::Apis::CloudsupportV2::ContentTypeInfo
gdata.* are outside protos with mising documentation Corresponds to the JSON property
contentTypeInfo. -
#cosmo_binary_reference ⇒ String
gdata.* are outside protos with mising documentation Corresponds to the JSON property
cosmoBinaryReferenceNOTE: Values are automatically base64 encoded/decoded in the client library. -
#crc32c_hash ⇒ Fixnum
gdata.* are outside protos with mising documentation Corresponds to the JSON property
crc32cHash. -
#diff_checksums_response ⇒ Google::Apis::CloudsupportV2::DiffChecksumsResponse
gdata.* are outside protos with mising documentation Corresponds to the JSON property
diffChecksumsResponse. -
#diff_download_response ⇒ Google::Apis::CloudsupportV2::DiffDownloadResponse
gdata.* are outside protos with mising documentation Corresponds to the JSON property
diffDownloadResponse. -
#diff_upload_request ⇒ Google::Apis::CloudsupportV2::DiffUploadRequest
gdata.* are outside protos with mising documentation Corresponds to the JSON property
diffUploadRequest. -
#diff_upload_response ⇒ Google::Apis::CloudsupportV2::DiffUploadResponse
gdata.* are outside protos with mising documentation Corresponds to the JSON property
diffUploadResponse. -
#diff_version_response ⇒ Google::Apis::CloudsupportV2::DiffVersionResponse
gdata.* are outside protos with mising documentation Corresponds to the JSON property
diffVersionResponse. -
#download_parameters ⇒ Google::Apis::CloudsupportV2::DownloadParameters
gdata.* are outside protos with mising documentation Corresponds to the JSON property
downloadParameters. -
#filename ⇒ String
gdata.* are outside protos with mising documentation Corresponds to the JSON property
filename. -
#hash_prop ⇒ String
gdata.* are outside protos with mising documentation Corresponds to the JSON property
hash. -
#hash_verified ⇒ Boolean
(also: #hash_verified?)
gdata.* are outside protos with mising documentation Corresponds to the JSON property
hashVerified. -
#inline ⇒ String
gdata.* are outside protos with mising documentation Corresponds to the JSON property
inlineNOTE: Values are automatically base64 encoded/decoded in the client library. -
#is_potential_retry ⇒ Boolean
(also: #is_potential_retry?)
gdata.* are outside protos with mising documentation Corresponds to the JSON property
isPotentialRetry. -
#length ⇒ Fixnum
gdata.* are outside protos with mising documentation Corresponds to the JSON property
length. -
#md5_hash ⇒ String
gdata.* are outside protos with mising documentation Corresponds to the JSON property
md5HashNOTE: Values are automatically base64 encoded/decoded in the client library. -
#media_id ⇒ String
gdata.* are outside protos with mising documentation Corresponds to the JSON property
mediaIdNOTE: Values are automatically base64 encoded/decoded in the client library. -
#object_id_prop ⇒ Google::Apis::CloudsupportV2::ObjectIdProp
gdata.* are outside protos with mising documentation Corresponds to the JSON property
objectId. -
#path ⇒ String
gdata.* are outside protos with mising documentation Corresponds to the JSON property
path. -
#reference_type ⇒ String
gdata.* are outside protos with mising documentation Corresponds to the JSON property
referenceType. -
#sha1_hash ⇒ String
gdata.* are outside protos with mising documentation Corresponds to the JSON property
sha1HashNOTE: Values are automatically base64 encoded/decoded in the client library. -
#sha256_hash ⇒ String
gdata.* are outside protos with mising documentation Corresponds to the JSON property
sha256HashNOTE: Values are automatically base64 encoded/decoded in the client library. -
#sha512_hash ⇒ String
gdata.* are outside protos with mising documentation Corresponds to the JSON property
sha512HashNOTE: Values are automatically base64 encoded/decoded in the client library. -
#timestamp ⇒ Fixnum
gdata.* are outside protos with mising documentation Corresponds to the JSON property
timestamp. -
#token ⇒ String
gdata.* are outside protos with mising documentation Corresponds to the JSON property
token.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Media
constructor
A new instance of Media.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Media
Returns a new instance of Media.
1070 1071 1072 |
# File 'lib/google/apis/cloudsupport_v2/classes.rb', line 1070 def initialize(**args) update!(**args) end |
Instance Attribute Details
#algorithm ⇒ String
gdata.* are outside protos with mising documentation
Corresponds to the JSON property algorithm
907 908 909 |
# File 'lib/google/apis/cloudsupport_v2/classes.rb', line 907 def algorithm @algorithm end |
#bigstore_object_ref ⇒ String
gdata.* are outside protos with mising documentation
Corresponds to the JSON property bigstoreObjectRef
NOTE: Values are automatically base64 encoded/decoded in the client library.
913 914 915 |
# File 'lib/google/apis/cloudsupport_v2/classes.rb', line 913 def bigstore_object_ref @bigstore_object_ref end |
#blob_ref ⇒ String
gdata.* are outside protos with mising documentation
Corresponds to the JSON property blobRef
NOTE: Values are automatically base64 encoded/decoded in the client library.
919 920 921 |
# File 'lib/google/apis/cloudsupport_v2/classes.rb', line 919 def blob_ref @blob_ref end |
#blobstore2_info ⇒ Google::Apis::CloudsupportV2::Blobstore2Info
gdata.* are outside protos with mising documentation
Corresponds to the JSON property blobstore2Info
924 925 926 |
# File 'lib/google/apis/cloudsupport_v2/classes.rb', line 924 def blobstore2_info @blobstore2_info end |
#composite_media ⇒ Array<Google::Apis::CloudsupportV2::CompositeMedia>
gdata.* are outside protos with mising documentation
Corresponds to the JSON property compositeMedia
929 930 931 |
# File 'lib/google/apis/cloudsupport_v2/classes.rb', line 929 def composite_media @composite_media end |
#content_type ⇒ String
gdata.* are outside protos with mising documentation
Corresponds to the JSON property contentType
934 935 936 |
# File 'lib/google/apis/cloudsupport_v2/classes.rb', line 934 def content_type @content_type end |
#content_type_info ⇒ Google::Apis::CloudsupportV2::ContentTypeInfo
gdata.* are outside protos with mising documentation
Corresponds to the JSON property contentTypeInfo
939 940 941 |
# File 'lib/google/apis/cloudsupport_v2/classes.rb', line 939 def content_type_info @content_type_info end |
#cosmo_binary_reference ⇒ String
gdata.* are outside protos with mising documentation
Corresponds to the JSON property cosmoBinaryReference
NOTE: Values are automatically base64 encoded/decoded in the client library.
945 946 947 |
# File 'lib/google/apis/cloudsupport_v2/classes.rb', line 945 def cosmo_binary_reference @cosmo_binary_reference end |
#crc32c_hash ⇒ Fixnum
gdata.* are outside protos with mising documentation
Corresponds to the JSON property crc32cHash
950 951 952 |
# File 'lib/google/apis/cloudsupport_v2/classes.rb', line 950 def crc32c_hash @crc32c_hash end |
#diff_checksums_response ⇒ Google::Apis::CloudsupportV2::DiffChecksumsResponse
gdata.* are outside protos with mising documentation
Corresponds to the JSON property diffChecksumsResponse
955 956 957 |
# File 'lib/google/apis/cloudsupport_v2/classes.rb', line 955 def diff_checksums_response @diff_checksums_response end |
#diff_download_response ⇒ Google::Apis::CloudsupportV2::DiffDownloadResponse
gdata.* are outside protos with mising documentation
Corresponds to the JSON property diffDownloadResponse
960 961 962 |
# File 'lib/google/apis/cloudsupport_v2/classes.rb', line 960 def diff_download_response @diff_download_response end |
#diff_upload_request ⇒ Google::Apis::CloudsupportV2::DiffUploadRequest
gdata.* are outside protos with mising documentation
Corresponds to the JSON property diffUploadRequest
965 966 967 |
# File 'lib/google/apis/cloudsupport_v2/classes.rb', line 965 def diff_upload_request @diff_upload_request end |
#diff_upload_response ⇒ Google::Apis::CloudsupportV2::DiffUploadResponse
gdata.* are outside protos with mising documentation
Corresponds to the JSON property diffUploadResponse
970 971 972 |
# File 'lib/google/apis/cloudsupport_v2/classes.rb', line 970 def diff_upload_response @diff_upload_response end |
#diff_version_response ⇒ Google::Apis::CloudsupportV2::DiffVersionResponse
gdata.* are outside protos with mising documentation
Corresponds to the JSON property diffVersionResponse
975 976 977 |
# File 'lib/google/apis/cloudsupport_v2/classes.rb', line 975 def diff_version_response @diff_version_response end |
#download_parameters ⇒ Google::Apis::CloudsupportV2::DownloadParameters
gdata.* are outside protos with mising documentation
Corresponds to the JSON property downloadParameters
980 981 982 |
# File 'lib/google/apis/cloudsupport_v2/classes.rb', line 980 def download_parameters @download_parameters end |
#filename ⇒ String
gdata.* are outside protos with mising documentation
Corresponds to the JSON property filename
985 986 987 |
# File 'lib/google/apis/cloudsupport_v2/classes.rb', line 985 def filename @filename end |
#hash_prop ⇒ String
gdata.* are outside protos with mising documentation
Corresponds to the JSON property hash
990 991 992 |
# File 'lib/google/apis/cloudsupport_v2/classes.rb', line 990 def hash_prop @hash_prop end |
#hash_verified ⇒ Boolean Also known as: hash_verified?
gdata.* are outside protos with mising documentation
Corresponds to the JSON property hashVerified
995 996 997 |
# File 'lib/google/apis/cloudsupport_v2/classes.rb', line 995 def hash_verified @hash_verified end |
#inline ⇒ String
gdata.* are outside protos with mising documentation
Corresponds to the JSON property inline
NOTE: Values are automatically base64 encoded/decoded in the client library.
1002 1003 1004 |
# File 'lib/google/apis/cloudsupport_v2/classes.rb', line 1002 def inline @inline end |
#is_potential_retry ⇒ Boolean Also known as: is_potential_retry?
gdata.* are outside protos with mising documentation
Corresponds to the JSON property isPotentialRetry
1007 1008 1009 |
# File 'lib/google/apis/cloudsupport_v2/classes.rb', line 1007 def is_potential_retry @is_potential_retry end |
#length ⇒ Fixnum
gdata.* are outside protos with mising documentation
Corresponds to the JSON property length
1013 1014 1015 |
# File 'lib/google/apis/cloudsupport_v2/classes.rb', line 1013 def length @length end |
#md5_hash ⇒ String
gdata.* are outside protos with mising documentation
Corresponds to the JSON property md5Hash
NOTE: Values are automatically base64 encoded/decoded in the client library.
1019 1020 1021 |
# File 'lib/google/apis/cloudsupport_v2/classes.rb', line 1019 def md5_hash @md5_hash end |
#media_id ⇒ String
gdata.* are outside protos with mising documentation
Corresponds to the JSON property mediaId
NOTE: Values are automatically base64 encoded/decoded in the client library.
1025 1026 1027 |
# File 'lib/google/apis/cloudsupport_v2/classes.rb', line 1025 def media_id @media_id end |
#object_id_prop ⇒ Google::Apis::CloudsupportV2::ObjectIdProp
gdata.* are outside protos with mising documentation
Corresponds to the JSON property objectId
1030 1031 1032 |
# File 'lib/google/apis/cloudsupport_v2/classes.rb', line 1030 def object_id_prop @object_id_prop end |
#path ⇒ String
gdata.* are outside protos with mising documentation
Corresponds to the JSON property path
1035 1036 1037 |
# File 'lib/google/apis/cloudsupport_v2/classes.rb', line 1035 def path @path end |
#reference_type ⇒ String
gdata.* are outside protos with mising documentation
Corresponds to the JSON property referenceType
1040 1041 1042 |
# File 'lib/google/apis/cloudsupport_v2/classes.rb', line 1040 def reference_type @reference_type end |
#sha1_hash ⇒ String
gdata.* are outside protos with mising documentation
Corresponds to the JSON property sha1Hash
NOTE: Values are automatically base64 encoded/decoded in the client library.
1046 1047 1048 |
# File 'lib/google/apis/cloudsupport_v2/classes.rb', line 1046 def sha1_hash @sha1_hash end |
#sha256_hash ⇒ String
gdata.* are outside protos with mising documentation
Corresponds to the JSON property sha256Hash
NOTE: Values are automatically base64 encoded/decoded in the client library.
1052 1053 1054 |
# File 'lib/google/apis/cloudsupport_v2/classes.rb', line 1052 def sha256_hash @sha256_hash end |
#sha512_hash ⇒ String
gdata.* are outside protos with mising documentation
Corresponds to the JSON property sha512Hash
NOTE: Values are automatically base64 encoded/decoded in the client library.
1058 1059 1060 |
# File 'lib/google/apis/cloudsupport_v2/classes.rb', line 1058 def sha512_hash @sha512_hash end |
#timestamp ⇒ Fixnum
gdata.* are outside protos with mising documentation
Corresponds to the JSON property timestamp
1063 1064 1065 |
# File 'lib/google/apis/cloudsupport_v2/classes.rb', line 1063 def @timestamp end |
#token ⇒ String
gdata.* are outside protos with mising documentation
Corresponds to the JSON property token
1068 1069 1070 |
# File 'lib/google/apis/cloudsupport_v2/classes.rb', line 1068 def token @token end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1075 1076 1077 1078 1079 1080 1081 1082 1083 1084 1085 1086 1087 1088 1089 1090 1091 1092 1093 1094 1095 1096 1097 1098 1099 1100 1101 1102 1103 1104 1105 1106 1107 |
# File 'lib/google/apis/cloudsupport_v2/classes.rb', line 1075 def update!(**args) @algorithm = args[:algorithm] if args.key?(:algorithm) @bigstore_object_ref = args[:bigstore_object_ref] if args.key?(:bigstore_object_ref) @blob_ref = args[:blob_ref] if args.key?(:blob_ref) @blobstore2_info = args[:blobstore2_info] if args.key?(:blobstore2_info) @composite_media = args[:composite_media] if args.key?(:composite_media) @content_type = args[:content_type] if args.key?(:content_type) @content_type_info = args[:content_type_info] if args.key?(:content_type_info) @cosmo_binary_reference = args[:cosmo_binary_reference] if args.key?(:cosmo_binary_reference) @crc32c_hash = args[:crc32c_hash] if args.key?(:crc32c_hash) @diff_checksums_response = args[:diff_checksums_response] if args.key?(:diff_checksums_response) @diff_download_response = args[:diff_download_response] if args.key?(:diff_download_response) @diff_upload_request = args[:diff_upload_request] if args.key?(:diff_upload_request) @diff_upload_response = args[:diff_upload_response] if args.key?(:diff_upload_response) @diff_version_response = args[:diff_version_response] if args.key?(:diff_version_response) @download_parameters = args[:download_parameters] if args.key?(:download_parameters) @filename = args[:filename] if args.key?(:filename) @hash_prop = args[:hash_prop] if args.key?(:hash_prop) @hash_verified = args[:hash_verified] if args.key?(:hash_verified) @inline = args[:inline] if args.key?(:inline) @is_potential_retry = args[:is_potential_retry] if args.key?(:is_potential_retry) @length = args[:length] if args.key?(:length) @md5_hash = args[:md5_hash] if args.key?(:md5_hash) @media_id = args[:media_id] if args.key?(:media_id) @object_id_prop = args[:object_id_prop] if args.key?(:object_id_prop) @path = args[:path] if args.key?(:path) @reference_type = args[:reference_type] if args.key?(:reference_type) @sha1_hash = args[:sha1_hash] if args.key?(:sha1_hash) @sha256_hash = args[:sha256_hash] if args.key?(:sha256_hash) @sha512_hash = args[:sha512_hash] if args.key?(:sha512_hash) @timestamp = args[:timestamp] if args.key?(:timestamp) @token = args[:token] if args.key?(:token) end |