Class: Google::Apis::CloudsupportV2::SupportEventSubscription
- Inherits:
-
Object
- Object
- Google::Apis::CloudsupportV2::SupportEventSubscription
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/cloudsupport_v2/classes.rb,
lib/google/apis/cloudsupport_v2/representations.rb,
lib/google/apis/cloudsupport_v2/representations.rb
Overview
A support event subscription.
Instance Attribute Summary collapse
-
#create_time ⇒ String
Output only.
-
#delete_time ⇒ String
Output only.
-
#failure_reason ⇒ String
Output only.
-
#name ⇒ String
Identifier.
-
#pub_sub_topic ⇒ String
Required.
-
#purge_time ⇒ String
Output only.
-
#state ⇒ String
Output only.
-
#update_time ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ SupportEventSubscription
constructor
A new instance of SupportEventSubscription.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ SupportEventSubscription
Returns a new instance of SupportEventSubscription.
1242 1243 1244 |
# File 'lib/google/apis/cloudsupport_v2/classes.rb', line 1242 def initialize(**args) update!(**args) end |
Instance Attribute Details
#create_time ⇒ String
Output only. The time at which the subscription was created.
Corresponds to the JSON property createTime
1203 1204 1205 |
# File 'lib/google/apis/cloudsupport_v2/classes.rb', line 1203 def create_time @create_time end |
#delete_time ⇒ String
Output only. The time at which the subscription was deleted.
Corresponds to the JSON property deleteTime
1208 1209 1210 |
# File 'lib/google/apis/cloudsupport_v2/classes.rb', line 1208 def delete_time @delete_time end |
#failure_reason ⇒ String
Output only. Reason why subscription is failing. State of subscription must be
FAILING in order for this to have a value.
Corresponds to the JSON property failureReason
1214 1215 1216 |
# File 'lib/google/apis/cloudsupport_v2/classes.rb', line 1214 def failure_reason @failure_reason end |
#name ⇒ String
Identifier. The resource name of the support event subscription.
Corresponds to the JSON property name
1219 1220 1221 |
# File 'lib/google/apis/cloudsupport_v2/classes.rb', line 1219 def name @name end |
#pub_sub_topic ⇒ String
Required. The name of the Pub/Sub topic to publish notifications to. Format:
projects/project/topics/topic
Corresponds to the JSON property pubSubTopic
1225 1226 1227 |
# File 'lib/google/apis/cloudsupport_v2/classes.rb', line 1225 def pub_sub_topic @pub_sub_topic end |
#purge_time ⇒ String
Output only. The time at which the subscription will be purged.
Corresponds to the JSON property purgeTime
1230 1231 1232 |
# File 'lib/google/apis/cloudsupport_v2/classes.rb', line 1230 def purge_time @purge_time end |
#state ⇒ String
Output only. The state of the subscription.
Corresponds to the JSON property state
1235 1236 1237 |
# File 'lib/google/apis/cloudsupport_v2/classes.rb', line 1235 def state @state end |
#update_time ⇒ String
Output only. The time at which the subscription was last updated.
Corresponds to the JSON property updateTime
1240 1241 1242 |
# File 'lib/google/apis/cloudsupport_v2/classes.rb', line 1240 def update_time @update_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1247 1248 1249 1250 1251 1252 1253 1254 1255 1256 |
# File 'lib/google/apis/cloudsupport_v2/classes.rb', line 1247 def update!(**args) @create_time = args[:create_time] if args.key?(:create_time) @delete_time = args[:delete_time] if args.key?(:delete_time) @failure_reason = args[:failure_reason] if args.key?(:failure_reason) @name = args[:name] if args.key?(:name) @pub_sub_topic = args[:pub_sub_topic] if args.key?(:pub_sub_topic) @purge_time = args[:purge_time] if args.key?(:purge_time) @state = args[:state] if args.key?(:state) @update_time = args[:update_time] if args.key?(:update_time) end |